from time import sleep
from .Start_simulation_fixture import tfs_instance, FixtureStartSimulations, EthProtocolType
from xtr import logging, Severity
logger = logging.getLogger(__name__)
# Create the test case class, that inherits from the preset TestFixture.


class TestTriggerSomeipEvent(FixtureStartSimulations):

    # Create setUp() method.
    def setUp(self):
        logger.info("Setup test case")

    # Create the tearDown() method.
    def tearDown(self):
        logger.info("Tear down test case")

    def test_trigger_event(self):
        Expected_payload = (0, 24, 0, 60, 1, 0, 0, 194,
                            221, 15, 64, 80, 1, 0, 0, 0)
        filter_someip = {
            'someip_header': {
                'service_identifier': 0x9003,
                'method_identifier': 0x8004,
                'message_type': 0x02},
            'ipv4_header': {
                'ip_address_source': '160.48.199.57'}}

        ECU4_ETHERNET = self.com_network.try_get_ecu_by_name('ECU4_ETHERNET')
        ECU2_ETHERNET = self.com_network.try_get_ecu_by_name('ECU2_ETHERNET')

        assert ECU2_ETHERNET is not None
        assert ECU4_ETHERNET is not None

        ECU2_ETHERNET.activate()
        ECU4_ETHERNET.activate()

        service_id = 0x9003
        method_id = 0x8004
        service = ECU4_ETHERNET.try_get_provided_service_by_name_or_id(
            service_id)
        assert service is not None
        event = service.try_get_message_by_id(method_id)
        assert event is not None

        sleep(1)
        self.bus_manager.ethernet_listener(
            "Ethernet4", EthProtocolType.IS_SOME_IP).start_listening(
            channel="Ethernet4", someip_filter=filter_someip)

        memeber = event.try_get_simple_member_by_path(
            "EVENT3_SERVICE1::actualStateStandstillFunctions")
        memeber.set_value(1)
        event.try_serialize_and_transmit()
        sleep(0.5)
        self.bus_manager.ethernet_listener(
            "Ethernet4", EthProtocolType.IS_SOME_IP).stop_listening()
        messages = self.bus_manager.ethernet_listener(
            "Ethernet4", EthProtocolType.IS_SOME_IP).get_queue()
        self.bus_manager.ethernet_listener(
            "Ethernet4", EthProtocolType.IS_SOME_IP).clean_up
        for message in messages:
            Actual_payload = tuple(message['someip_message'].payload)
        logger.info(Actual_payload)
        self.assertEqual(Actual_payload[12:],
                         Expected_payload[12:],
                         Severity.BLOCKER,
                         f"rrr{Actual_payload[12:]}")
